<!--
SPDX-FileCopyrightText: 2021 Johannes Loher <johannes.loher@fg4f.de>

SPDX-License-Identifier: MIT
-->

# Risk Dice Modifier

An implementation of risk rolls as found for example in the Splittermond game
system.

This module provides a new dice modifier `ri` for regular Dice. This modifier
causes the dice roller to keep / drop dice according to the following rules:
- If there are either two `1`s or a `1` and a `2` in the results, keep only
  these dice.
- Otherwise, keep the two dice with the highest results.

```
/roll 4d10ri # Roll 4d10 in risk die mode
```

![Risk Dice Modifier](./risk-dice-modifier.png)

## Installation

To install and use the Risk Dice Modifier module for Foundry Virtual Tabletop,
simply paste the following URL into the **Install Module** dialog on the Setup
menu of the application.

https://git.f3l.de/ghost/risk-dice-modifier/-/raw/latest/src/module.json?inline=false

## Development

### Prerequisites

In order to build this module, recent versions of `node` and `yarn` are required.
We recommend using the latest lts version of `node`, which is `v14.15.4` at the
time of writing. If you use `nvm` to manage your `node` versions, you can simply
run
```
nvm install
```

in the project's root directory.

You also need to install the the project's dependencies. To do so, run

```
yarn install
```

### Building

You can build the project by running

```
yarn build
```

Alternatively, you can run

```
yarn build:watch
```

to watch for changes and automatically build as necessary.

### Linking the built module to Foundry VTT

In order to provide a fluent development experience, it is recommended to link
the built system to your local Foundry VTT installation's data folder. In order
to do so, first add a file called `foundryconfig.json` to the project root with
the following content:

```
{
    "dataPath": "<path to your home directory>/.local/share/FoundryVTT/Data"
}
```

On platforms other than Linux you need to adjust the path accordingly.

Then run

```
yarn link-project
```

## Licensing

This project is being developed under the terms of the [LIMITED LICENSE
AGREEMENT FOR MODULE DEVELOPMENT](https://foundryvtt.com/article/license/) for
Foundry Virtual Tabletop.

The project itself is licensed under multiple licenses. It is difficult to keep
this section up to date, so here is a brief summary as of June 2021:

* Files under `.yarn/` are from [yarn] and licensed under the [BSD-2-Clause]
  license.
* Images are licensed under the [CC-BY-4.0] license.
* Other files are licensed under the [MIT] license.

For more accurate information, check the individual files.

[BSD-2-Clause]: LICENSES/BSD-2-Clause.txt
[CC-BY-4.0]: LICENSES/CC-BY-4.0.txt
[MIT]: LICENSES/MIT.txt
[yarn]: https://github.com/yarnpkg/berry
