// SPDX-FileCopyrightText: 2021 Johannes Loher <johannes.loher@fg4f.de>
//
// SPDX-License-Identifier: MIT

export function risk(this: DiceTerm): void | DiceTerm {
    const activeResults = this.results.filter((result) => result.active);
    const activeValues = activeResults.map((result) => result.result);

    activeResults.forEach((result) => {
        markResultInactive(result);
    });

    if (activeValues.includes(1) && activeValues.includes(2)) {
        markFirstOneAndFirstTwoActive(activeResults);
    } else if (activeValues.filter((value) => value === 1).length > 1) {
        markFirstTwoOnesActive(activeResults);
    } else {
        markTwoBiggestResultsActive(activeResults);
    }
}

function markResultInactive(result: DiceTerm.Result): void {
    result.active = false;
    result.discarded = true;
}

function markResultActive(result: DiceTerm.Result): void {
    result.active = true;
    result.discarded = false;
}

function markFirstOneAndFirstTwoActive(results: DiceTerm.Result[]): void {
    const firstOne = results.find((result) => result.result === 1);
    if (firstOne) markResultActive(firstOne);

    const firstTwo = results.find((result) => result.result === 2);
    if (firstTwo) markResultActive(firstTwo);
}

function markFirstTwoOnesActive(results: DiceTerm.Result[]): void {
    const [firstOne, secondOne] = results.filter((result) => result.result === 1);
    firstOne.active = true;
    firstOne.discarded = false;
    secondOne.active = true;
    secondOne.discarded = false;
}

function markTwoBiggestResultsActive(results: DiceTerm.Result[]): void {
    [...results]
        .sort((a, b) => b.result - a.result)
        .slice(0, 2)
        .forEach((result) => {
            result.active = true;
            result.discarded = false;
        });
}
